@@ -97,16 +97,6 @@ test_paths <- function(callr_drop, callr_keep,
   check_env(out$env)
 }
 
-skip_if_offline <- function(host = "httpbin.org", port = 80) {
-
-  res <- tryCatch(
-    pingr::ping_port(host, count = 1L, port = port),
-    error = function(e) NA
-  )
-
-  if (is.na(res)) skip("No internet connection")
-}
-
 test_temp_file <- function(fileext = "", pattern = "test-file-",
                            envir = parent.frame(), create = TRUE) {
   tmp <- tempfile(pattern = pattern, fileext = fileext)
@@ -169,3 +159,40 @@ without_env <- function(f) {
   environment(f) <- .GlobalEnv
   f
 }
+
+expect_r_process_snapshot <- function(..., interactive = TRUE, echo = TRUE,
+                                      transform = NULL, variant = NULL) {
+  # errors.R assumes non-interactive in testthat, but we don't want that
+  withr::local_envvar(TESTTHAT = NA_character_)
+  dots <- eval(substitute(alist(...)))
+  nms <- names(dots)
+  if (all(nms == "")) {
+    code_pos <- rep(TRUE, length(dots))
+  } else {
+    code_pos <- nms == ""
+  }
+  code <- unlist(lapply(dots[code_pos], deparse))
+  args <- dots[!code_pos]
+
+  record_output <- asciicast::record_output
+  output <- do.call(
+    "record_output",
+    c(list(code), args, interactive = interactive, echo = echo)
+  )
+
+  r_process <- function() writeLines(output)
+
+  expect_snapshot(r_process(), transform = transform, variant = variant)
+}
+
+redact_srcref <- function(x) {
+  sub("[ ]*at [-a-zA-Z0-9]+[.]R:[0-9]+:[0-9]+?", "", x)
+}
+
+redact_callr_rs_result <- function(x) {
+  sub("done callr-rs-result-[a-f0-9]+", "done callr-rs-result-<id>", x)
+}
+
+fix_eol <- function(x) {
+  gsub("\\r\\n", "\\n", x, fixed = TRUE)
+}
