@@ -1,6 +1,4 @@
 
-context("r_session")
-
 test_that("regular use", {
   rs <- r_session$new()
   on.exit(rs$kill())
@@ -116,8 +114,7 @@ test_that("interrupt", {
   rs$interrupt()
   rs$poll_process(1000)
   res <- rs$read()
-  expect_s3_class(res$error, "rlib_error")
-  expect_s3_class(res$error$parent$error, "interrupt")
+  expect_s3_class(res$error, "callr_timeout_error")
   rs$close()
 })
 
@@ -259,6 +256,7 @@ test_that("custom load hook", {
 })
 
 test_that("traceback", {
+  withr::local_options(callr.traceback = TRUE)
   rs <- r_session$new()
   on.exit(rs$kill(), add = TRUE)
 
@@ -270,9 +268,7 @@ test_that("traceback", {
 
   expect_error(rs$run(do), "oops")
   expect_output(tb <- rs$traceback(), "1: \"?f()\"?")
-  if (getRversion() >= "3.3.0" && getRversion() <= "4.0.0") {
-    expect_match(c(tb[[4]]), "f()", fixed = TRUE)
-  }
+  expect_match(c(tb[[3]]), "f()", fixed = TRUE)
 })
 
 test_that("error in the load hook", {
@@ -287,7 +283,7 @@ test_that("error in the load hook", {
 
   processx::poll(list(rs2$get_poll_connection()), 3000)
   msg <- rs2$read()
-  expect_equal(msg$code, 501L)
+  expect_true(msg$code %in% c(501L, 502L))
   expect_match(msg$stderr, "oops")
 })
 
